==> libgphoto2_2.5.2.orig.tar.gz: libgphoto2-api.html/gphoto2-file_8c.js <==
var gphoto2-file_8c =
[
    [ "_CameraFile", "struct__CameraFile.html", "struct__CameraFile" ],
    [ "_BSD_SOURCE", "gphoto2-file_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73", null ],
    [ "_POSIX_SOURCE", "gphoto2-file_8c.html#ac3d144aa01e765a1fae62ab5491c7cc1", null ],
    [ "CHECK_MEM", "gphoto2-file_8c.html#aefa85642ca98f16c304f90dd7c760c6b", null ],
    [ "CHECK_NULL", "gphoto2-file_8c.html#a31f5b59ba0bbc5f65f733ef299e2533d", null ],
    [ "CHECK_RESULT", "gphoto2-file_8c.html#a1061828e4e2cafb14086ac2bed47f80d", null ],
    [ "MAX_PATH", "gphoto2-file_8c.html#ab99ded389af74001a6298fc9e44e74e5", null ],
    [ "gp_file_adjust_name_for_mime_type", "gphoto2-file_8c.html#a73b0c6e00946621ea45b3a04d92165a2", null ],
    [ "gp_file_append", "gphoto2-file_8c.html#a9a7b8e9c05a8e9cac6d2d8abe6b03928", null ],
    [ "gp_file_clean", "gphoto2-file_8c.html#a6fca699d500239610e276fef064adc2f", null ],
    [ "gp_file_copy", "gphoto2-file_8c.html#a9aa6499669a0ab66844030440655a0ff", null ],
    [ "gp_file_detect_mime_type", "gphoto2-file_8c.html#ac31856165a1b0fb6e64b06a5a47b8cc7", null ],
    [ "gp_file_free", "gphoto2-file_8c.html#ac0058da71651fd4068306be65fa680cc", null ],
    [ "gp_file_get_data_and_size", "gphoto2-file_8c.html#afe4a2c1685df174f61f20b2986edd93b", null ],
    [ "gp_file_get_mime_type", "gphoto2-file_8c.html#a4415b2867b1a8d6c032018db99fd3fee", null ],
    [ "gp_file_get_mtime", "gphoto2-file_8c.html#aba965b1a676ea68194cb4052b3dea00d", null ],
    [ "gp_file_get_name", "gphoto2-file_8c.html#a58b455d8aa49d2a01429ce3475c9f873", null ],
    [ "gp_file_get_name_by_type", "gphoto2-file_8c.html#ab9c078f6915a3186c90ff81cc52da898", null ],
    [ "gp_file_new", "gphoto2-file_8c.html#af0d1d638d7a58ae9591be458eeb13c72", null ],
    [ "gp_file_new_from_fd", "gphoto2-file_8c.html#a0376d5d1c7af0edde33cdbe7f3d2eb1e", null ],
    [ "gp_file_new_from_handler", "gphoto2-file_8c.html#aeee98c1292b35cdb5905c9dc93ac4db1", null ],
    [ "gp_file_open", "gphoto2-file_8c.html#a77b7d521ef9e2bf405e97717dd836d43", null ],
    [ "gp_file_ref", "gphoto2-file_8c.html#aca2b7ed7d1b91fcdb0578ee71142a101", null ],
    [ "gp_file_save", "gphoto2-file_8c.html#a56e413d5ea3abc6e512b92c5861b9594", null ],
    [ "gp_file_set_data_and_size", "gphoto2-file_8c.html#a7ceb7a1907b15f7b34a7f2418b48973a", null ],
    [ "gp_file_set_mime_type", "gphoto2-file_8c.html#ab0c9c2ff2ef54f2ead016ed5a82f895f", null ],
    [ "gp_file_set_mtime", "gphoto2-file_8c.html#ae2f0802d187957c104a3bb6925edc95a", null ],
    [ "gp_file_set_name", "gphoto2-file_8c.html#ab2fc202bdab8503ab5dca38357dff494", null ],
    [ "gp_file_slurp", "gphoto2-file_8c.html#a53f5f6a8338c9889645b658be2d9e5c4", null ],
    [ "gp_file_unref", "gphoto2-file_8c.html#aa330c62c510ed9c05a678a319ff807a6", null ],
    [ "mime_table", "gphoto2-file_8c.html#af33eddcbfe6cdbda48978976249944cd", null ]
];

==> libgphoto2_2.5.4.orig.tar.gz: libgphoto2-api.html/gphoto2-file_8c.js <==
var gphoto2_file_8c =
[
    [ "_CameraFile", "struct__CameraFile.html", "struct__CameraFile" ],
    [ "_BSD_SOURCE", "gphoto2-file_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73", null ],
    [ "_POSIX_SOURCE", "gphoto2-file_8c.html#ac3d144aa01e765a1fae62ab5491c7cc1", null ],
    [ "CHECK_MEM", "gphoto2-file_8c.html#aefa85642ca98f16c304f90dd7c760c6b", null ],
    [ "CHECK_NULL", "gphoto2-file_8c.html#a31f5b59ba0bbc5f65f733ef299e2533d", null ],
    [ "CHECK_RESULT", "gphoto2-file_8c.html#a1061828e4e2cafb14086ac2bed47f80d", null ],
    [ "MAX_PATH", "gphoto2-file_8c.html#ab99ded389af74001a6298fc9e44e74e5", null ],
    [ "gp_file_adjust_name_for_mime_type", "gphoto2-file_8c.html#a73b0c6e00946621ea45b3a04d92165a2", null ],
    [ "gp_file_append", "gphoto2-file_8c.html#a9a7b8e9c05a8e9cac6d2d8abe6b03928", null ],
    [ "gp_file_clean", "gphoto2-file_8c.html#a6fca699d500239610e276fef064adc2f", null ],
    [ "gp_file_copy", "gphoto2-file_8c.html#a9aa6499669a0ab66844030440655a0ff", null ],
    [ "gp_file_detect_mime_type", "gphoto2-file_8c.html#ac31856165a1b0fb6e64b06a5a47b8cc7", null ],
    [ "gp_file_free", "gphoto2-file_8c.html#ac0058da71651fd4068306be65fa680cc", null ],
    [ "gp_file_get_data_and_size", "gphoto2-file_8c.html#afe4a2c1685df174f61f20b2986edd93b", null ],
    [ "gp_file_get_mime_type", "gphoto2-file_8c.html#a4415b2867b1a8d6c032018db99fd3fee", null ],
    [ "gp_file_get_mtime", "gphoto2-file_8c.html#aba965b1a676ea68194cb4052b3dea00d", null ],
    [ "gp_file_get_name", "gphoto2-file_8c.html#a58b455d8aa49d2a01429ce3475c9f873", null ],
    [ "gp_file_get_name_by_type", "gphoto2-file_8c.html#ab9c078f6915a3186c90ff81cc52da898", null ],
    [ "gp_file_new", "gphoto2-file_8c.html#af0d1d638d7a58ae9591be458eeb13c72", null ],
    [ "gp_file_new_from_fd", "gphoto2-file_8c.html#a0376d5d1c7af0edde33cdbe7f3d2eb1e", null ],
    [ "gp_file_new_from_handler", "gphoto2-file_8c.html#aeee98c1292b35cdb5905c9dc93ac4db1", null ],
    [ "gp_file_open", "gphoto2-file_8c.html#a77b7d521ef9e2bf405e97717dd836d43", null ],
    [ "gp_file_ref", "gphoto2-file_8c.html#aca2b7ed7d1b91fcdb0578ee71142a101", null ],
    [ "gp_file_save", "gphoto2-file_8c.html#a56e413d5ea3abc6e512b92c5861b9594", null ],
    [ "gp_file_set_data_and_size", "gphoto2-file_8c.html#a7ceb7a1907b15f7b34a7f2418b48973a", null ],
    [ "gp_file_set_mime_type", "gphoto2-file_8c.html#ab0c9c2ff2ef54f2ead016ed5a82f895f", null ],
    [ "gp_file_set_mtime", "gphoto2-file_8c.html#ae2f0802d187957c104a3bb6925edc95a", null ],
    [ "gp_file_set_name", "gphoto2-file_8c.html#ab2fc202bdab8503ab5dca38357dff494", null ],
    [ "gp_file_slurp", "gphoto2-file_8c.html#a53f5f6a8338c9889645b658be2d9e5c4", null ],
    [ "gp_file_unref", "gphoto2-file_8c.html#aa330c62c510ed9c05a678a319ff807a6", null ]
];
